@@ -4,7 +4,6 @@ export {FastCheckboxGroup} from "./fast/fast_checkbox_group"
 export {FastSwitchGroup} from "./fast/fast_switch_group"
 export {FastTextAreaInput} from "./fast/fast_textarea_input"
 export {FastTextInput} from "./fast/fast_text_input"
-export {PerspectiveViewer} from "./perspective_viewer"
 export {PivotTable} from "./pivot_table"
-export {TabulatorModel} from "./tabulator_model"
+export {Icon} from "./icon"
 export {WebComponent} from "./web_component"
